# 更新日志
## KAA
### v2025.3.1.0
脚本：
* [新增] 新增支持指定回忆编成编号（#6482962）
* [新增] 优化培育与日常流程，修复一些 bug（#145f97f）
* [新增] 支持处理外出行动 & 优化部分流程（#03fdfaa）
* [新增] 新增支持处理技能卡强化选择事件（#133f084）
* [新增] 培育中支持识别睡意 T 卡（眠気）（#5a68500）
* [修复] 修复课程中无法处理当前回合无剩余手牌的情况（#bfb574c）
* [修复] 修复课程中遇到四/五张手牌时会卡住的问题（#ae22253）
* [修复] 修复某些情况下会卡在培育开始第二步（#73dc4d8）
* [修复] 修复某些情况下会卡在工作分配偶像选择页面（#2ff655f）

界面：
* [新增] UI 上新增更新日志 Tab（#07be7b3）
* [新增] 新增一键上传日志报告功能（#62d5805）

框架：
* [新增] device.click() 方法新增支持传入 tuple[int, int]（#f146038）
* [新增] adb_raw 截图方法加入超时自动重试（#08f382c）
* [新增] 为 device.click() 方法添加可视调试信息（#be37164）
* [新增] 为 adb_raw 截图方式的截图线程加入自动重试（#9b25098）
* [修复] 修复了 device.click() 调试信息在没有截图数据时会报错（#f0a3baa）
* [修复] 修复写入调试数据前不会自动清空上次数据的问题（#80e04ee）

其他：
* [新增] ImageAnntation 页面与 Python 代码引入 HintPoint 支持（#949e28d）
* [修复] 修复某些情况下会卡在领取任务奖励处（#f80660e）
* [单测] 移除无用单元测试（#54f9b03）

### v2025.2.23.0
修复：
* 返回首页时无法处理弹出某些弹窗
* 培育中，某些情况下会卡在饮料领取弹窗
* 培育中，某些情况下会在饮料领取时报错

新增：
* 支持处理游戏本体更新弹窗
* 培育中，支持处理技能卡移除事件
* 培育结束时，支持处理“偶像强化月”活动的新纪录弹窗
* UI 标题上新增版本号显示

### v2025.2.20.1
修复：
* ADB 设备连接失败的问题

### v2025.2.20.0
初始版本。